searchData={"items":[{"type":"module","title":"CliMate","doc":"This module is the base namespace for the `:cli_mate` application.\n\nMost interactions with this library will be made through the `CliMate.CLI`\nmodule.","ref":"CliMate.html"},{"type":"module","title":"Deprecation for `use CliMate` {: .warning} - CliMate","doc":"Including all CLI code in your own module is no longer supported and will be\nremovedin a future release.\n\nPlease see\nhttps://github.com/lud/cli_mate?tab=readme-ov-file#migration-to-version-100\n\nIf you still want to extend the CLI module to add your own helpers, you can use\nthe following:\n\n    require CliMate\n    CliMate.extend_cli()\n\nThis will import and re-export all the CLI exported functions into your module.","ref":"CliMate.html#module-deprecation-for-use-climate-warning"},{"type":"macro","title":"CliMate.extend_cli/0","doc":"Imports and re-exports all `CliMate.CLI` functions in the calling module.\n\nThis is useful if you want to define a module where all your CLI helpers\nreside, instead of calling, say, `writeln(\"hello\")` from `CliMate.CLI` but\n`fancy_subtitle(\"Hello!\")` from `MyApp.CliHelpers`.\n\nAlthough, it will be easier to debug and provide useful documentation if you\n_do_ call the functions from their origin module.","ref":"CliMate.html#extend_cli/0"},{"type":"module","title":"CliMate.Argument","doc":"Describes an argument.\n\nWhen declaring a command, the `:arguments` entry is a keyword list that\naccepts these settings, all optional:\n\n* `:required` - A boolean. Arguments are required by default.\n* `:type` - `:string`, `:integer` or `:float`. Defaults to `:string`.\n* `:doc` - A string to document what the argument is for. This is not used at\n  the moment but future releases will exploit it.\n* `:cast` - A fun accepting the value, or a `{module, function, arguments}`,\n  returning a result tuple.  See the \"Casting\" section below for more\n  information.","ref":"CliMate.Argument.html"},{"type":"module","title":"Casting - CliMate.Argument","doc":"When the `:cast` option is a fun, it will be called with the deserialized\nvalue. When it is an \"MFA\" tuple, the deserialized value will be prepended to\nthe given arguments.\n\n#### Cast functions input\n\nWhat is a deserialized value though? By default it will be the raw string\npassed in the shell as command line arguments. But if the `:type` option is\nalso defined to `:integer` or `:float`, your cast function will be called with\nthe corresponding type. If that type deserialization fails, the cast function\nwill not be called.\n\n#### Returning errors\n\nCast functions must return `{:ok, value}` or `{:error, reason}`. The `reason`\ncan be anything, but at the moment CliMate does no spcial formatting on it to\ndisplay errors (besides calling `to_string/1` with a safe fallback to\n`inspect/1`). It is advised to return a meaninful error message as the reason.\n\n#### Compilation commands\n\nWhen commands are declared as a module attribute, you cannot use local\nfunctions definitions or the compilation will fail with \"undefined function\n...\". You need to use a remote form by prefixing by `__MODULE__`, or use an\nMFA tuple.\n\n    defmodule MyCommand do\n      use Mix.Task\n\n      @command name: \"my command\",\n               arguments: [\n                 some_arg: [\n                   cast: &__MODULE__.cast_some/1\n                 ]\n               ]\n    end","ref":"CliMate.Argument.html#module-casting"},{"type":"function","title":"CliMate.Argument.new/2","doc":"","ref":"CliMate.Argument.html#new/2"},{"type":"type","title":"CliMate.Argument.t/0","doc":"","ref":"CliMate.Argument.html#t:t/0"},{"type":"type","title":"CliMate.Argument.vtype/0","doc":"","ref":"CliMate.Argument.html#t:vtype/0"},{"type":"module","title":"CliMate.CLI","doc":"Main API to interact with the command line.","ref":"CliMate.CLI.html"},{"type":"module","title":"Basic usage - CliMate.CLI","doc":"import CliMate.CLI\n\n    def run(argv) do\n      command = [options: [verbose: [type: :boolean]], arguments: [n: [type: :integer]]]\n      %{options: opts, arguments: args} = parse_or_halt!(argv, command)\n\n      if opts.verbose do\n        writeln(\"Hello!\")\n      end\n\n      case do_something_useful(args.n) do\n        :ok -> halt_success(\"Done!\")\n        {:error, reason} -> halt_error(reason)\n      end\n    end","ref":"CliMate.CLI.html#module-basic-usage"},{"type":"function","title":"CliMate.CLI.color/2","doc":"Outputs `iodata` in the current shell, wrapped with formatting\ninformation, such as `[color, iodata, :default_color]`.\n\n`color` should be a `IO.ANSI.format/2` compatible atom.","ref":"CliMate.CLI.html#color/2"},{"type":"function","title":"CliMate.CLI.debug/1","doc":"Outputs `iodata` in the current shell, formatted with cyan color.","ref":"CliMate.CLI.html#debug/1"},{"type":"function","title":"CliMate.CLI.error/1","doc":"Outputs `iodata` to `stderr` in the current shell, formatted with bright\nred color.","ref":"CliMate.CLI.html#error/1"},{"type":"function","title":"CliMate.CLI.format_usage/2","doc":"Returns a standard \"usage\" documentation block describing the different\noptions of the given command.","ref":"CliMate.CLI.html#format_usage/2"},{"type":"function","title":"Options - CliMate.CLI.format_usage/2","doc":"* `:format` - If `:moduledoc`, the formatted usage will be compatible for\n  embedding in a `@moduledoc` attribute. Any other value will generate a\n  simple terminal styled text. Defaults to `:cli`.\n* `:io_columns` - Number of columns for the terminal, defaults to a call to\n  `:io.columns/0`. Only used when format is `:cli`.","ref":"CliMate.CLI.html#format_usage/2-options"},{"type":"function","title":"CliMate.CLI.halt/1","doc":"Stops the execution of the Erlang runtime, with a given return code.\n\nIf not provided, the return code will be `0`.","ref":"CliMate.CLI.html#halt/1"},{"type":"function","title":"CliMate.CLI.halt_error/2","doc":"Combines `error/1` then `halt/1`. Halts the Erlang runtime with a `1`\nreturn code by default.","ref":"CliMate.CLI.html#halt_error/2"},{"type":"function","title":"CliMate.CLI.halt_success/1","doc":"Combines `success/1` then `halt/1`. Halts the Erlang runtime with a `0`\nreturn code.","ref":"CliMate.CLI.html#halt_success/1"},{"type":"function","title":"CliMate.CLI.parse/2","doc":"Accepts the command line arguments and the definition of a command (options,\narguments, and metadata) and returns a parse result with flues extracted from\nthe command line arguments.","ref":"CliMate.CLI.html#parse/2"},{"type":"function","title":"Defining options - CliMate.CLI.parse/2","doc":"Options definitions is a `Keyword` whose keys are the option name, and values\nare the options parameters. Note that keys with underscores like `some_thing`\ndefine options in kebab case like `--some-thing`.\n\nThe available settings for an option are described in the `CliMate.Option`\nmodule.\n\nNote that the `:help` option is always defined and cannot be overridden.","ref":"CliMate.CLI.html#parse/2-defining-options"},{"type":"function","title":"Options examples - CliMate.CLI.parse/2","doc":"iex> {:ok, result} = parse(~w(--who joe), [options: [who: [type: :string]]])\n    iex> result.options.who\n    \"joe\"\n\n    iex> {:ok, result} = parse(~w(--who joe), [options: [who: []]])\n    iex> result.options.who\n    \"joe\"\n\n    iex> {:ok, result} = parse(~w(--port 4000), [options: [port: [type: :integer]]])\n    iex> result.options.port\n    4000\n\n    iex> {:ok, result} = parse(~w(-p 4000), [options: [port: [type: :integer, short: :p]]])\n    iex> result.options.port\n    4000\n\n    iex> parse(~w(--port nope), [options: [port: [type: :integer]]])\n    {:error, {:invalid, [{\"--port\", \"nope\"}]}}\n\n    iex> {:ok, result} = parse([], [options: [lang: [default: \"elixir\"]]])\n    iex> result.options.lang\n    \"elixir\"\n\n    iex> {:ok, result} = parse([], [options: [lang: []]])\n    iex> Map.has_key?(result.options, :lang)\n    false\n\n    iex> {:ok, result} = parse([], options: [])\n    iex> result.options.help\n    false\n\n    iex> {:ok, result} = parse(~w(--help), options: [])\n    iex> result.options.help\n    true","ref":"CliMate.CLI.html#parse/2-options-examples"},{"type":"function","title":"Defining arguments - CliMate.CLI.parse/2","doc":"Arguments can be defined in the same way as options, providing a `Keyword`\nwhere the keys are the argument names and the values are the parameters.\n\nThe available settings for an argument are described in the `CliMate.Argument`\nmodule.","ref":"CliMate.CLI.html#parse/2-defining-arguments"},{"type":"function","title":"Arguments examples - CliMate.CLI.parse/2","doc":"iex> {:ok, result} = parse(~w(joe), arguments: [who: []])\n    iex> result.arguments.who\n    \"joe\"\n\n    iex> parse([], arguments: [who: []])\n    {:error, {:missing_argument, :who}}\n\n    iex> {:ok, result} = parse([], arguments: [who: [required: false]])\n    iex> result.arguments\n    %{}\n\n    iex> cast = fn string -> Date.from_iso8601(string) end\n    iex> {:ok, result} = parse([\"2022-12-22\"], arguments: [date: [cast: cast]])\n    iex> result.arguments.date\n    ~D[2022-12-22]\n\n    iex> cast = {Date, :from_iso8601, []}\n    iex> {:ok, result} = parse([\"2022-12-22\"], arguments: [date: [cast: cast]])\n    iex> result.arguments.date\n    ~D[2022-12-22]\n\n    iex> cast = {Date, :from_iso8601, []}\n    iex> parse([\"not-a-date\"], arguments: [date: [cast: cast]])\n    {:error, {:argument_cast, :date, :invalid_format}}","ref":"CliMate.CLI.html#parse/2-arguments-examples"},{"type":"function","title":"CliMate.CLI.parse_or_halt!/2","doc":"Attempts to parse the command line arguments `argv` with the defined\ncommand.\n\nCommand options and arguments are documented in the `parse/2` function of\nthis module.\n\nIn `parse_or_halt!/2`, the successful return value will not be wrapped in\nan `:ok` tuple, but directly a map with the `:options` and `:arguments`\nkeys.\n\nIn case of a parse error, this function will output the usage block\nfollowed by a formatted error message, and halt the Erlang runtime.","ref":"CliMate.CLI.html#parse_or_halt!/2"},{"type":"function","title":"CliMate.CLI.put_shell/1","doc":"Defines the current shell to send console messages to. Accepts either\n`CliMate.CLI` or `CliMate.CLI.ProcessShell`.\n\nThis is mostly done for testing. The default shell outputs to standard io as\nyou would expect.\n\nThe shell is saved to `:persistent_term`, so shell should not be changed\nrepeatedly during runtime. This method of persistence is subject to change and\nshould not be relied on.","ref":"CliMate.CLI.html#put_shell/1"},{"type":"function","title":"CliMate.CLI.safe_to_string/1","doc":"Returns a string representation of the given term, with fallback to\n`Kernel.inspect/1`.","ref":"CliMate.CLI.html#safe_to_string/1"},{"type":"function","title":"CliMate.CLI.shell/0","doc":"Returns the current shell to send output to.","ref":"CliMate.CLI.html#shell/0"},{"type":"function","title":"CliMate.CLI.success/1","doc":"Outputs `iodata` in the current shell, formatted with green color.","ref":"CliMate.CLI.html#success/1"},{"type":"function","title":"CliMate.CLI.warn/1","doc":"Outputs `iodata` to `stderr` in the current shell, formatted with yellow\ncolor.","ref":"CliMate.CLI.html#warn/1"},{"type":"function","title":"CliMate.CLI.writeln/1","doc":"Outputs `iodata` in the current shell.","ref":"CliMate.CLI.html#writeln/1"},{"type":"module","title":"CliMate.Option","doc":"Describes an option.\n\nWhen declaring a command, the `:options` entry is a keyword list that accepts\nthese settings, all optional:\n\n* `:type` - `CliMate` uses the `OptionParser` module under the hood, so the\n  following types are accepted:\n  * `:boolean` - If the default value is `true`, `OptionParser` supports the\n    `--no-` prefix to the options.\n  * `:count` - Counts the number of times the flag is given.\n  * `:integer` - Value is parsed or an error is returned.\n  * `:float` - Same as `:integer`.\n  * `:string` - Value is used as-is.\n* `:doc` - A string describing the role of the option. It is displayed in the\n  usage block shown with `--help` or `mix help`.\n* `:short` - A single letter atom like `:a`, `:b`, etc. For instance with\n  these options:\n\n      @command options: [\n        name: [short: :n]\n      ]\n\n* `:default` - The default value to set if the option is not given. See the\n  \"Default values\" section below.\n\n  The command line will accept both `--name` and `-n` switches.\n\n* `:keep` - A boolean. This flag is used with `OptionParser`. When `true`\n  duplicate options will not override each other but will rather be\n  accumulated in a list. The option value will always be a list even when\n  provided a single time in the command line arguments. The option will also\n  be present, as an empty list, if the option is not given in command line\n  arguments.\n* `:doc_arg` - A string to display in the usage block. Defaults the type of\n  the option, as in:\n\n  ```text\n  Options\n\n    -n --some-int    This option does not define :doc_arg.\n    -o --other-int     Here \"other\" was provided as :doc_arg.\n  ```\n* `:default_doc` - The string to output when CliMate does not know how to\n  display the default value. That is, when the default value is defined by a\n  function. Not used when `:default` is not defined.","ref":"CliMate.Option.html"},{"type":"module","title":"Default values - CliMate.Option","doc":"Default values can be omitted, in that case, the option will not be present at\nall when `CliMate.CLI.parse/2` will be called. This is especially important\nfor booleans, where one would expect that they automatically default to false.\nIt is not the case.\n\nWhen defined, a default value can be:\n\n* A raw value, that is anything that is not a function. This value will be\n  used as the default value.\n* A function of arity zero. This function will be called when the option is\n  not provided in the command line and the result value will be used as the\n  default value. For instance `fn -> 123 end` or `&default_for_some_opt/0`.\n* A function of arity one. This function will be called with the option key as\n  its argument. For instance, passing `&default_opt/1` as the `:default` for\n  an option definition allow to define the following function:\n\n      defp default_opt(:port), do: 4000\n      defp default_opt(:scheme), do: \"http\"\n\nNote that when the command is defined in a module attribute, you need to pass\nthe module prefix or the compilation will fail:\n\n    defmodule MyCommand do\n      use Mix.Task\n\n      @command name: \"my command\",\n               options: [\n                 some_arg: [\n                   default: &__MODULE__.cast_some/1\n                 ]\n               ]\n    end","ref":"CliMate.Option.html#module-default-values"},{"type":"function","title":"CliMate.Option.new/2","doc":"","ref":"CliMate.Option.html#new/2"},{"type":"type","title":"CliMate.Option.t/0","doc":"","ref":"CliMate.Option.html#t:t/0"},{"type":"type","title":"CliMate.Option.vtype/0","doc":"","ref":"CliMate.Option.html#t:vtype/0"},{"type":"module","title":"CliMate.ProcessShell","doc":"An output shell implementation allowing your CLI commands to send their output\nas messages to themselves. This is most useful for tests.\n\nThe process that will receive the messages is found by looking up the first\npid in the `:\"$callers\"` key of the process dictionary, or `self()` if there\nis no caller.\n\nUse `CliMate.put_shell(CliMate.ProcessShell)` to enable this shell.\n\nThis shell is called when calling one of:\n\n* `CliMate.CLI.error/1\n* `CliMate.CLI.warn/1\n* `CliMate.CLI.debug/1\n* `CliMate.CLI.success/1\n* `CliMate.CLI.writeln/1\n* `CliMate.CLI.halt_success/1\n* `CliMate.CLI.halt_error/1\n* `CliMate.CLI.halt_error/2\n\nA message of type `t:shell_message/0` will be sent to `self()`, or the caller\nprocess for `Task.async/1` and similar task functions.","ref":"CliMate.ProcessShell.html"},{"type":"function","title":"CliMate.ProcessShell.build_message/2","doc":"","ref":"CliMate.ProcessShell.html#build_message/2"},{"type":"type","title":"CliMate.ProcessShell.kind/0","doc":"","ref":"CliMate.ProcessShell.html#t:kind/0"},{"type":"function","title":"CliMate.ProcessShell.message_target/0","doc":"Returns the pid of the process that will receive output messages.","ref":"CliMate.ProcessShell.html#message_target/0"},{"type":"type","title":"CliMate.ProcessShell.shell_message/0","doc":"","ref":"CliMate.ProcessShell.html#t:shell_message/0"},{"type":"task","title":"mix example","doc":"Formats an integer in base two or eight","ref":"Mix.Tasks.Example.html"},{"type":"task","title":"Usage - mix example","doc":"```shell\nmix example [options]    \n```","ref":"Mix.Tasks.Example.html#module-usage"},{"type":"task","title":"Options - mix example","doc":"* `-v, --verbose`- Output debug info about the command. Defaults to `false`.\n* `--help`- Displays this help.","ref":"Mix.Tasks.Example.html#module-options"},{"type":"function","title":"Mix.Tasks.Example.cast_base/1","doc":"","ref":"Mix.Tasks.Example.html#cast_base/1"},{"type":"extras","title":"License","doc":"# The MIT License\n\nCopyright (c) 2022, Ludovic Demblans\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of\nthis software and associated documentation files (the \"Software\"), to deal in\nthe Software without restriction, including without limitation the rights to\nuse, copy, modify, merge, publish, distribute, sublicense, and/or sell copies\nof the Software, and to permit persons to whom the Software is furnished to do\nso, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# CliMate\n\nA Command-Line-Interface solution for Elixir.\n\nThis library provides:\n\n* A command line options and arguments parser implemented as a lightweight\n  wrapper around [OptionParser](https://hexdocs.pm/elixir/OptionParser.html)\n  that allows to define options, documentation and arguments in one data\n  structure.\n* Shell helpers to format shell outputs for releases where `Mix` is not\n  available.\n* Usage formatting and printing for `--help` and `mix help`.","ref":"readme.html"},{"type":"extras","title":"Table of contents - Overview","doc":"- [Table of contents](#table-of-contents)\n- [Installation](#installation)\n- [Basic usage](#basic-usage)\n  - [Describe a command](#describe-a-command)\n  - [Provide options and arguments docs for `mix help`](#provide-options-and-arguments-docs-for-mix-help)\n  - [Parse the command arguments](#parse-the-command-arguments)\n  - [Display the usage block](#display-the-usage-block)\n- [Migration to version 0.7.0](#migration-to-version-070)\n- [Building CLI applications in Elixir](#building-cli-applications-in-elixir)\n- [Roadmap](#roadmap)","ref":"readme.html#table-of-contents"},{"type":"extras","title":"Installation - Overview","doc":"```elixir\ndef deps do\n  [\n    {:cli_mate, \"~> 0.7\",runtime: false},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic usage - Overview","doc":"To illustrate how that library work we will implement an example Mix task that\nprints an integer in base 2 or 8.\n\n\nThe first step is to declare the module as a Mix task and alias the\n`CliMate.CLI` module (or import it!).\n\n```elixir\ndefmodule Mix.Tasks.Example do\n  alias CliMate.CLI\n  use Mix.Task\n\n  # ...\nend\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Describe a command - Overview","doc":"Then we define a command in your module. That command can be defined as a\nvariable directly in the `run/1` callback, or returned by a function, etc. It's\na simple raw value. In this example we define it as a module attribute so we can\nprint the usage for `mix help`.\n\n```elixir\n  @command name: \"mix example\",\n           options: [\n             verbose: [\n               short: :v,\n               type: :boolean,\n               default: false,\n               doc: \"Output debug info about the command.\"\n             ]\n           ],\n           arguments: [\n             n: [type: :integer],\n             base: [cast: &__MODULE__.cast_base/1]\n           ]\n```\n\nWe gave `\"mix example\"` as the name because this is how it is supposed to be\ninvoked. This we be displayed in the help and usage generated text. If you are\nbuilding an escript this should be the name of your executable instead.\n\nWe can now declare the documentation for the module:","ref":"readme.html#describe-a-command"},{"type":"extras","title":"Provide options and arguments docs for `mix help` - Overview","doc":"```elixir\n  @shortdoc \"Formats an integer in base two or eight\"\n\n  @moduledoc \"\"\"\n  #{@shortdoc}\n\n  #{CliMate.CLI.format_usage(@command, format: :moduledoc)}\n  \"\"\"\n```\n\nThis will output something like that (with colors now shown here):\n\n```\n%> mix help example\n\n                       mix example\n\nFormats an integer in base two or eight","ref":"readme.html#provide-options-and-arguments-docs-for-mix-help"},{"type":"extras","title":"Usage - Overview","doc":"mix example [options]","ref":"readme.html#usage"},{"type":"extras","title":"Options - Overview","doc":"• -v, --verbose - Output debug info about the\n    command. Defaults to false.\n  • --help - Displays this help.\n\nLocation: _build/dev/lib/cli_mate/ebin\n```","ref":"readme.html#options"},{"type":"extras","title":"Parse the command arguments - Overview","doc":"And finally our implementation!\n\n```elixir\n  @impl true\n  def run(argv) do\n    %{options: opts, arguments: args} = CLI.parse_or_halt!(argv, @command)\n\n    formatted = Integer.to_string(args.n, args.base)\n\n    if opts.verbose do\n      IO.puts(\"#{args.n} in base #{args.base} is #{formatted}\")\n    else\n      IO.puts(formatted)\n    end\n  end\n\n  def cast_base(\"two\"), do: {:ok, 2}\n  def cast_base(\"eight\"), do: {:ok, 8}\n  def cast_base(_), do: {:error, :invalid_base}\n```\n\nThe `CLI.parse_or_halt!/2` function will return a map with the `:options` and\n`:arguments` as maps. The values in those maps are casted according to the\n`:type` of an option and the `:type` and/or `:cast` of an argument.\n\nThe function will also stop if one of those casting functions fails.\n\nFinally, this function will also halt the VM normally if the `--help` option is\nprovided. This option is built in and does not need to be defined.","ref":"readme.html#parse-the-command-arguments"},{"type":"extras","title":"Display the usage block - Overview","doc":"All commands in CliMate support a `--help` option by default. This is useful\nwhen Mix is not available. In this example we can still call that with mix:\n\n```\n%> mix example --help\nUsage\n\n  mix example [options]    \n\nOptions\n\n  -v --verbose     Output debug info about the command.\n                   Defaults to false.\n     --help        Displays this help.\n  ```","ref":"readme.html#display-the-usage-block"},{"type":"extras","title":"Migration to version 0.7.0 - Overview","doc":"The orginal version of CliMate included the CLI code in a consumer module, using\n`use CliMate`. This allowed library authors to use CliMate in mix tasks that\ncould be installed by users with `mix archive.install hex some_package`.\nArchives installed that way cannot have dependencies so CliMate was providing a\nway to use it anyway.\n\nBut this solution had too much problems regarding code loading with the recent\nversions of Elixir. So we are stopping support for this feature.\n\nThe best way to provide commands with dependencies is to provide an\n[escript](https://hexdocs.pm/mix/main/Mix.Tasks.Escript.Build.html) or something\nlike [burrito](https://github.com/burrito-elixir/burrito).","ref":"readme.html#migration-to-version-0-7-0"},{"type":"extras","title":"Building CLI applications in Elixir - Overview","doc":"Note that due to the startup time of the BEAM, is is sometimes discouraged to\nbuild command line applications with Elixir.\n\nWhile the startup problem is real, this is only important for small utilities\nlike `ls`, `grep` or `cat`. You surely do not want that delay when piping or\nlooping with those commands in bash scripts.\n\nBut for commands that are doing more, like deployments or asset bundling, or\ntools that run for a while like credo or dialyzer it is totally fine. And you\nget to write them with Elixir!","ref":"readme.html#building-cli-applications-in-elixir"},{"type":"extras","title":"Roadmap - Overview","doc":"We would like to support the following in future releases:\n\n* [ ] Merge code from Argument and Option to provide same capabilities of native\n  and custom type casting.\n* [ ] Support subcommands for escripts.","ref":"readme.html#roadmap"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}